@@ -3,6 +3,7 @@ Pypodo scripts
 """
 
 import re
+from columnar import columnar
 from pypodo.properties import (
     REGEX_INDEX,
 )
@@ -22,11 +23,19 @@ def find(openfile=open):
     Search with regex in the todofile
     """
     empty = True
+    headers = ["index","task","tags"]
+    data = []
     with open(todofilefromconfig(), "r") as todofile:
         for line in todofile.readlines():
             search = compute_args().search
             if re.findall(search, line.rstrip("\n")):
-                printlinetodo(line)
+                data.append(printlinetodo(line))
                 empty = False
     if empty:
         printwarning("the filtered todolist is empty")
+    else:
+        if compute_args().condensate:
+            table = columnar(data, no_borders=True, wrap_max=0)
+        else:
+            table = columnar(data, headers, no_borders=False, wrap_max=0)            
+        print(table)     
\ No newline at end of file
